=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2006-12-21 01:08:21 +0000
+++ loggerhead/controllers/__init__.py	2007-01-02 02:23:47 +0000
@@ -47,15 +47,16 @@
     return re.sub(r'[^\w\d_]', '_', s)
 
 
-class Group (object):
+class Project (object):
     def __init__(self, name, config):
         self.name = name
         self.friendly_name = config.get('name', name)
         self.description = config.get('description', '')
+        self.long_description = config.get('long_description', '')
         
         self._views = []
         for view_name in config.sections:
-            log.debug('Configuring (group %r) branch %r...', name, view_name)
+            log.debug('Configuring (project %r) branch %r...', name, view_name)
             c_view_name = cherrypy_friendly(view_name)
             view = BranchView(name, c_view_name, config[view_name])
             self._views.append(view)
@@ -67,25 +68,24 @@
 class Root (controllers.RootController):
     def __init__(self):
         global my_config
-        self._groups = []
-        for group_name in my_config.sections:
-            # FIXME: clean out any non-python chars
-            c_group_name = cherrypy_friendly(group_name)
-            group = Group(c_group_name, my_config[group_name])
-            self._groups.append(group)
-            setattr(self, c_group_name, group)
+        self._projects = []
+        for project_name in my_config.sections:
+            c_project_name = cherrypy_friendly(project_name)
+            project = Project(c_project_name, my_config[project_name])
+            self._projects.append(project)
+            setattr(self, c_project_name, project)
         
     @turbogears.expose(template='loggerhead.templates.browse')
     def index(self):
         return {
-            'groups': self._groups,
+            'projects': self._projects,
             'util': util,
             'title': my_config.get('title', ''),
         }
 
     def _check_rebuild(self):
-        for g in self._groups:
-            for v in g.views:
+        for p in self._projects:
+            for v in p.views:
                 v.check_rebuild()
 
 

=== modified file 'loggerhead/static/css/style.css'
--- loggerhead/static/css/style.css	2006-12-29 02:42:07 +0000
+++ loggerhead/static/css/style.css	2007-01-02 02:23:47 +0000
@@ -564,7 +564,7 @@
 
 /* ----- top-level browse page ----- */
 
-.browse-group-name {
+.browse-project-name {
     background-color: #dee7ec;
     padding-top: 5px;
     padding-bottom: 5px;
@@ -575,6 +575,13 @@
     font-weight: bold;
 }
 
+.browse-project-description {
+	padding-top: 1em;
+	padding-bottom: 1em;
+	margin-left: 2em;
+    width: 90%;
+}
+	
 .browse-view {
 	margin-top: 1em;
 	margin-bottom: 1em;

=== modified file 'loggerhead/templates/browse.kid'
--- loggerhead/templates/browse.kid	2006-12-21 00:30:31 +0000
+++ loggerhead/templates/browse.kid	2007-01-02 02:23:47 +0000
@@ -13,9 +13,13 @@
     <span py:if="not title"> bazaar branches in loggerhead </span>
 </h1>
 
-<div class="browse-group" py:for="group in groups">
-    <div class="browse-group-name">
-        ${group.friendly_name}
+<div class="browse-project" py:for="project in projects">
+    <div class="browse-project-name">
+        ${project.friendly_name}
+    </div>
+    
+    <div class="browse-project-description" py:if="len(project.long_description) > 0">
+    ${XML(project.long_description)}
     </div>
     
     <div class="browse-view">
@@ -25,9 +29,9 @@
             <th> Description </th>
             <th> Last change </th>
         </tr>
-        <span py:for="view in group.views">
+        <span py:for="view in project.views">
             <tr>
-            <td class="name"> <a href="${tg.url([ '/' + group.name, view.name ])}">${view.friendly_name}</a> </td>
+            <td class="name"> <a href="${tg.url([ '/' + project.name, view.name ])}">${view.friendly_name}</a> </td>
             <td class="description"> ${view.description} </td>
             <td class="last-update"> <!--${view.last_updated().strftime('%d %b %Y')} &nbsp;--> ${util.ago(view.last_updated())} </td>
             </tr>

